summaryrefslogtreecommitdiffstats
path: root/src/mesa/state_tracker/st_program.h
diff options
context:
space:
mode:
authorTimothy Arceri <[email protected]>2016-10-19 13:23:37 +1100
committerTimothy Arceri <[email protected]>2016-10-26 14:29:36 +1100
commit3423488d55b9c483fcdb3996eb89b424c1031d24 (patch)
tree270d90fe3fd4c090f2c8e59a3b20d0afe7d98e72 /src/mesa/state_tracker/st_program.h
parent17e28a1571b6141368fefc84cc8b0a3b4e52f8ee (diff)
st/mesa/r200/i915/i965: eliminate gl_fragment_program
Here we move OriginUpperLeft and PixelCenterInteger into gl_program all other fields have been replace by shader_info. V2: Don't use anonymous union/structs to hold vertex/fragment fields suggested by Ian. Reviewed-by: Jason Ekstrand <[email protected]>
Diffstat (limited to 'src/mesa/state_tracker/st_program.h')
-rw-r--r--src/mesa/state_tracker/st_program.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mesa/state_tracker/st_program.h b/src/mesa/state_tracker/st_program.h
index deb7009bfac..eb36ac32825 100644
--- a/src/mesa/state_tracker/st_program.h
+++ b/src/mesa/state_tracker/st_program.h
@@ -136,11 +136,11 @@ struct st_fp_variant
/**
* Derived from Mesa gl_fragment_program:
*/
struct st_fragment_program
{
- struct gl_fragment_program Base;
+ struct gl_program Base;
struct pipe_shader_state tgsi;
struct glsl_to_tgsi_visitor* glsl_to_tgsi;
struct ati_fragment_shader *ati_fs;
@@ -197,7 +197,7 @@ struct st_vp_variant
/**
* Derived from Mesa gl_fragment_program:
*/
struct st_vertex_program
{
@@ -302,7 +302,7 @@ struct st_compute_program
static inline struct st_fragment_program *
-st_fragment_program( struct gl_fragment_program *fp )
+st_fragment_program( struct gl_program *fp )
{
return (struct st_fragment_program *)fp;
}
@@ -136,11 +136,11 @@ struct st_fp_variant
/**
- * Derived from Mesa gl_fragment_program:
+ * Derived from Mesa gl_program:
*/
struct st_fragment_program
@@ -197,7 +197,7 @@ struct st_vp_variant
/**
- * Derived from Mesa gl_fragment_program:
+ * Derived from Mesa gl_program:
*/
struct st_vertex_program